==> haskell-quickcheck-instances-0.3.16-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-instances
version: 0.3.16
id: quickcheck-instances-0.3.16-1e3UqzXiLOyALTYmVjqoLP
key: quickcheck-instances-0.3.16-1e3UqzXiLOyALTYmVjqoLP
license: BSD3
copyright: Copyright Antoine Latter, 2012-2014
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/qc-instances
synopsis: Common quickcheck instances
description:
    QuickCheck instances.
    .
    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.
    .
    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.
    .
    For information on writing a test-suite with Cabal
    see <https://www.haskell.org/cabal/users-guide/developing-packages.html#test-suites>
category: Testing
author: Antoine Latter <aslatter@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Test.QuickCheck.Instances
abi: 598ed02bf30986e2ae92e8588b38ed30
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/quickcheck-instances-0.3.16
library-dirs: /usr/lib/ghc-8.2.1/site-local/quickcheck-instances-0.3.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/quickcheck-instances-0.3.16
hs-libraries: HSquickcheck-instances-0.3.16-1e3UqzXiLOyALTYmVjqoLP
depends:
    base-4.10.0.0 QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1
    array-0.5.2.0 base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    bytestring-0.10.8.2 case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    containers-0.5.10.2 hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    uuid-types-1.0.3-JRgobIDHEgPC3wNlzbV76R
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1=2c4212a9c69c9d234eb81396b5fd082b
             array-0.5.2.0=044554210403f250e868a2183de060a9
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=c240e412bac64503e37397debf06fa14
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h=9b88a29fc517c1a42f17e665c48bfa0f
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG=ef0c2166834103b504bc3792a7d2c177
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v=cbaa4957cb14b8a9e85ebeab0ab7d6ba
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             uuid-types-1.0.3-JRgobIDHEgPC3wNlzbV76R=2d77c31fd392dbe2ac4f8b371809e3ab
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
haddock-interfaces: /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-instances-0.3.16-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-instances
version: 0.3.16
id: quickcheck-instances-0.3.16-LeXGXWc1Sov3fkkaL3Jmgi
key: quickcheck-instances-0.3.16-LeXGXWc1Sov3fkkaL3Jmgi
license: BSD3
copyright: Copyright Antoine Latter, 2012-2014
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/qc-instances
synopsis: Common quickcheck instances
description:
    QuickCheck instances.
    .
    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.
    .
    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.
    .
    For information on writing a test-suite with Cabal
    see <https://www.haskell.org/cabal/users-guide/developing-packages.html#test-suites>
category: Testing
author: Antoine Latter <aslatter@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Test.QuickCheck.Instances
abi: 69b5fbbff03492240fce36cfbd3ef83f
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/quickcheck-instances-0.3.16
library-dirs: /usr/lib/ghc-8.2.1/site-local/quickcheck-instances-0.3.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/quickcheck-instances-0.3.16
hs-libraries: HSquickcheck-instances-0.3.16-LeXGXWc1Sov3fkkaL3Jmgi
depends:
    base-4.10.0.0 QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX
    array-0.5.2.0 base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    bytestring-0.10.8.2 case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    containers-0.5.10.2 hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    uuid-types-1.0.3-JRgobIDHEgPC3wNlzbV76R
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX=31c7a57798b8306ee987164ad717d7a8
             array-0.5.2.0=044554210403f250e868a2183de060a9
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=c240e412bac64503e37397debf06fa14
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h=9b88a29fc517c1a42f17e665c48bfa0f
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG=ef0c2166834103b504bc3792a7d2c177
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v=cbaa4957cb14b8a9e85ebeab0ab7d6ba
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             uuid-types-1.0.3-JRgobIDHEgPC3wNlzbV76R=2d77c31fd392dbe2ac4f8b371809e3ab
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
haddock-interfaces: /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
